@@ -37,18 +37,20 @@ class WebsocketService(APIRouter):
 
     @api_route('/update/channel', description="get value")
     def update_channels(self):
-        self.update_channels_db()
-
-        new_channels = session.query(OkexWebsocketChannels).all()
-        new_channels = [eval(channel.channel_str) for channel in new_channels]
-
-        old_channels_str = [str(channel) for channel in self.connect.channels]
-        new_channels_str = [str(channel) for channel in new_channels]
-        if new_channels_str is not None and len(new_channels_str) > 0:
-            if len(list(set(old_channels_str) - set(new_channels_str))) == len(
-                    list(set(new_channels_str) - set(old_channels_str))) == 0:
-                logging.info(f"old:{old_channels_str},new:{new_channels_str}")
-                self.connect.channels = new_channels
-                self.connect.subscribe_restart()
+        try:
+            self.update_channels_db()
 
+            new_channels = session.query(OkexWebsocketChannels).all()
+            new_channels = [eval(channel.channel_json) for channel in new_channels]
 
+            old_channels_str = [str(channel) for channel in self.connect.channels]
+            new_channels_str = [str(channel) for channel in new_channels]
+            if new_channels_str is not None and len(new_channels_str) > 0:
+                if len(list(set(old_channels_str) - set(new_channels_str))) == len(
+                        list(set(new_channels_str) - set(old_channels_str))) == 0:
+                    logging.info(f"old:{old_channels_str},new:{new_channels_str}")
+                    self.connect.channels = new_channels
+                    self.connect.subscribe_restart()
+            return {"update": "success"}
+        except Exception as e:
+            return {"update": "fails", "error": str(e)}
